=== modified file 'codeigniter/application/controllers/ManageCourses.php'
--- codeigniter/application/controllers/ManageCourses.php	2013-05-20 09:33:34 +0000
+++ codeigniter/application/controllers/ManageCourses.php	2013-05-22 11:39:03 +0000
@@ -2,25 +2,55 @@
 
 class ManageCourses extends CI_Controller {
 
+	/* 
+	 * tempLogin and tempLogout are temporary functions to debug user validation functionality
+	 * They should be removed when lenasys is complete
+	 */
+	
+	public function tempLogin() {
+		$this->load->model('user');
+		$loginDetails = array(
+			'username' => 'tempTeacher',
+			'name' => 'tempFoo',
+			'usertype' => 'Teacher',
+			'ssn' => '0000');
+		$this->session->set_userdata('authenticated', $loginDetails);
+		redirect('/ManageCourses');
+	}
+
+	public function tempLogout() {
+		$this->load->model('user');
+		$this->session->unset_userdata('authenticated');
+		redirect('/ManageCourses');
+	}
+
+
+	/*
+	 *	Manage courses index page
+	 *  RESTRICTED-LEVEL: Teacher
+	 */
 	public function index()
 	{
-		$this->load->library('session');
-		$this->load->helper('form');
-
 		/* Loads used models */
 		$this->load->model('user');
 		$this->load->model('admin/admin_model');
 		$this->load->model('ExamplesModel');
+
+		$this->load->library('session');
+		$this->load->helper('form');
 		
 		// Arrays
 		$headTagData = array(
 			'cssFiles' => array('header', 'examplesMenu', 'manageCoursesBody'),
 			'jsFiles' => array('header', 'examplesMenu', 'examplesBody', 'userControls', 'manageCourses')
 		);
+
 		$userInfo = array(
 			'userType' => $this->user->getUserType(), // Loads different header for teacher/student
 			'userName' => $this->user->getUserName()
 		);
+
+		
 		$allTitles = array();
 		$allCourses = array();
 		
@@ -47,18 +77,44 @@
 			}
 		}
 
-		/* Loads coursedata into $allCourses */
-		$courses = $this->admin_model->getCourses();
-
 		/* Loads views */
 		$this->load->view('headTag', array('headTagData' => $headTagData));
 		$this->load->view('header', $userInfo);
 		$this->load->view('examplesMenu', array('titles' => $allTitles));	
+
+		// Check user login and display message if not logged in
+				// User has to be logged in and usertype has to be Tea
+		if(!$this->user->isLoggedIn() || $this->user->getUserType() != "Teacher") {
+			$this->load->view('manageCoursesMessage', array('message' => 'You do not have access to this page'));
+			return;
+		}
+
+		/* Loads coursedata into $allCourses */
+		$courses = $this->admin_model->getCourses();
+
 		$this->load->view('manageCoursesBody', array("courses" => $courses));	
 
 	}
-	public function add_Course(){
-		// FIXA HR	
+
+
+	/*
+	 *	Add course page - handles form submission from index page 
+	 *  RESTRICTED-LEVEL: Teacher
+	 */
+	public function addCourse(){
+		$this->load->model('user');
+
+		// User has to be logged in and usertype has to be Tea
+		if(!$this->user->isLoggedIn() || $this->user->getUserType() != "Teacher") {
+			$this->load->view('manageCoursesMessage', array('message' => 'You do not have access to this page'));
+			return;
+		}
+
+		/* 
+			To do: 
+				Login validation
+				Input validation
+		*/
 		if($this->input->post('cid')){
 			$this->load->model('admin/admin_model');
 			$this->admin_model->addCourse($_POST['cid'], $_POST['name'], $_POST['courseData']);
@@ -67,6 +123,27 @@
 		else{
 			redirect("/ManageCourses");
 		}
+	} 	
+
+	/*
+	 *	Edit course page - handles form submission from index page 
+	 *  RESTRICTED-LEVEL: Teacher
+	 */
+	function editCourse() {
+		$this->load->model('user');
+		// User has to be logged in and usertype has to be Teacher
+		if(!$this->user->isLoggedIn() || $this->user->getUserType() != "Teacher") {
+			$this->load->view('manageCoursesMessage', array('message' => 'You do not have access to this page'));
+			return;
+		}
+
+		if($this->input->post('editCourseID')) {
+			$this->load->model('admin/admin_model');
+			$this->admin_model->editCourse($this->input->post('editCourseID'), $this->input->post('editCourseName'), $this->input->post('editCourseData'));
+			redirect('/ManageCourses');
+		} else {
+			echo "Something went wrong";
+		}
 	}
 	
 	public function validate() {

=== modified file 'codeigniter/application/models/admin/admin_model.php'
--- codeigniter/application/models/admin/admin_model.php	2013-05-20 09:33:34 +0000
+++ codeigniter/application/models/admin/admin_model.php	2013-05-22 11:39:03 +0000
@@ -29,6 +29,16 @@
 
 	}
 
+	function editCourse($cid, $name, $courseData) {
+		$data = array(
+			'name' => $name,
+			'courseData' => $courseData
+		);
+
+		$this->db->where('courseID', $cid);
+		$this->db->update('Courses', $data);
+	}
+
 	function getMenu(){
 		$menu = array();
 		$courses = $this->db->get("Courses");

=== modified file 'codeigniter/application/views/manageCoursesBody.php'
--- codeigniter/application/views/manageCoursesBody.php	2013-05-20 09:33:34 +0000
+++ codeigniter/application/views/manageCoursesBody.php	2013-05-22 11:39:03 +0000
@@ -1,104 +1,79 @@
-
-<!-- examplesBody.php -->
-	<div id="exampleBodyMenu">
-		<h1 class="viewTitle">Manage Courses</h1>
-		 <!-- Only displayed when teacher -->
-		<a class="btn cp" id="addCoursebutton">Add course</a>
-	</div>
-
-	<div id="bodyContainer">
-	
-		<div id="manageCoursesHeader">
-			<div class="column1">
-				<h2 class="manageCourseBodyHeader">Course Name</h2>
-			</div>
-			<div class="column2">
-				<h2 class="manageCourseBodyHeader">Course Code</h2>
-			</div>
-			<div class="column3">
-				<h2 class="manageCourseBodyHeader">Description</h2>
-			</div>
-			<div class="column4">
-				<h2 class="manageCourseBodyHeader">Published</h2>
-			</div>
-			<div class="column5">
-			</div>
-		</div>
-		
-		<!-- Loops down below makes it possible to load values from a source -->		
-		<?php
-			foreach ($courses as $item){
-			
-				echo 	'<div id="'.$item->name.'" class="banner row">
-					<div class="column1">
-					<h1 class="courseName">
-						'.$item->name.'
-					</h1>
-					</div>
-					<div class="column2">
-					<h1 class="courseName">
-						'.$item->courseID.'
-					</h1>
-					</div>
-					<div class="column3">
-					<h1 class="courseName">
-						'.$item->courseData.'
-					</h1>
-					</div>
-					<div class="column4">
-						knapp finnas kanske
-					</div>
-					<div class="column5">
-						<a href="#" class="manageCourseButton">C</a>
-					</div>
-				</div>';
-		}
-		?>
-	</div>
-	<div id="addCourse">
-		<h2 class="popupHeader">Add Course</h2>
-		<div class="middleLayerPopupsSizeTwo">
-			<div class="formColumn1">
-			<?php echo form_open(base_url().'ManageCourses/add_course'); ?>
-				<p class="formText">Course Name</p> 
-				<p class="formText">Course Code</p> 
-				<p class="formText">Course Description</p> 
-			</div>
-			<div class="formColumn2">
-				<input class="text" type="text" size="10" name="name" placeholder="-- Course Name --"/>
-				<input class="text" type="text" size="10" name="cid" placeholder="-- Course Code --"/>
-				<input class="text" type="text" size="10" name="courseData" placeholder="-- Course Description --"/>
-				<input type="submit" class="popupButtons btn" value="Confirm">
-				<input type="button" onClick="addCourseButtonHide()" class="popupButtons btn" value="Cancel">
-			</div>
-		</div>
-	</div>	
-	
-	<div id="editCourse">
-		<h2 class="popupHeader">Edit Course</h2>
-		<div class="middleLayerPopupsSizeTwo">
-			<div class="tableRow">
-			<?php echo form_open(base_url().'ManageCourses/edit_course'); ?>
-				<p class="tableCell">Course Name</p> 
-				<input class="text" type="text" size="10" name="name" value="NUVARANDE"/>
-			</div>
-			<div class="tableRow">
-				<p class="tableCell">Course Code</p> 
-				<input class="text" type="text" size="10" name="cid" value="NUVARANDE"/>
-			</div>
-
-			<div class="tableRow">
-				<p class="tableCell">Course Description</p> 
-				<input class="text" type="text" size="10" name="courseData" value="NUVARANDE"/>
-			</div>
-
-		</div>
-		<div>
-			<input type="submit" class="popupButtons btn" value="Confirm">
-			<input type="button" onClick="addCourseButtonHide()" class="popupButtons btn" value="Cancel">
-		</div>	
-	</div>
-	
-	</div>
-</body>
+			<div id="manageCourses">
+			<!-- examplesBody.php -->
+				<div id="manageCoursesMenu">
+					<h1 class="viewTitle">Manage Courses</h1>
+					 <!-- Only displayed when teacher -->
+					<a class="btn" id="addCourseButton" href="#">Add course</a>
+				</div>
+
+				<div id="bodyContainer">
+					<table>
+						<tr>
+							<th>Course Name</th>
+							<th>Course Code</th>
+							<th>Description</th>
+							<th>Edit Course Details</th>
+						</tr>
+						<? foreach($courses as $item): ?>
+						<tr data-course="<?= $item->courseID; ?>">
+							<td class="courseName"><?= $item->name; ?></td>
+							<td class="courseID"><?= $item->courseID; ?></td>
+							<td class="courseData"><?= $item->courseData; ?></td>
+							<td><a href="#" class="manageCourseButton">Manage Course</a></td>
+						</tr>
+						<? endforeach; ?>
+					</table>
+				</div>
+				<div id="addCourse" class="manageCoursePopup">
+					<h2 class="popupHeader">Add Course</h2>
+					<?= form_open(base_url().'ManageCourses/addCourse'); ?>
+						<ul>
+							<li>
+								<label for="addCourseID">Course Code:</label>
+								<input type="text" class="text" name="addCourseID" id="addCourseID" placeHolder="Course Code">
+							</li>
+							<li>
+								<label for="addCourseName">Course Name:</label>
+								<input type="text" class="text" name="addCourseName" id="addCourseName" placeHolder="Course Name">
+							</li>
+							<li>
+								<label for="addCourseData">Course Description:</label>
+								<input type="text" class="text" name="addCourseData" id="addCourseData" placeHolder="Course Description">
+							</li>
+						</ul>
+						<div class="manageCoursePopupMenu">
+							<button class="popupButtons btn" type="submit">Confirm</button>
+							<button class="cancelButton popupButtons btn">Cancel</button>
+						</div>
+					<?= form_close(); ?>
+				</div>	
+				
+				<div id="editCourse" class="manageCoursePopup">
+					<h2 class="popupHeader">Edit Course</h2>
+					<?= form_open(base_url().'ManageCourses/editCourse'); ?>
+						<ul>
+							<li>
+								<label for="editCourseID">Course Code:</label>
+								<span>Course Code</span>
+								<input type="hidden" id="editCourseID" name="editCourseID">
+							</li>
+							<li>
+								<label for="editCourseName">Course Name:</label>
+								<input type="text" class="text" name="editCourseName" id="editCourseName">
+							</li>
+							<li>
+								<label for="editCourseData">Course Description:</label>
+								<input type="text" class="text" name="editCourseData" id="editCourseData">
+							</li>
+						</ul>
+						<div class="manageCoursePopupMenu">
+							<button class="popupButtons btn" type="submit">Confirm</button>
+							<button class="cancelButton popupButtons btn">Cancel</button>
+						</div>
+					<?= form_close(); ?>
+				</div>	
+			</div><!-- end #manageCourses -->
+		</div> <!-- end #wrapper -->
+	</body>
 </html>
+	
\ No newline at end of file

=== added file 'codeigniter/application/views/manageCoursesMessage.php'
--- codeigniter/application/views/manageCoursesMessage.php	1970-01-01 00:00:00 +0000
+++ codeigniter/application/views/manageCoursesMessage.php	2013-05-22 11:39:03 +0000
@@ -0,0 +1,3 @@
+<div id="manageCourses">
+	<p><?=$message;?></p>
+</div>
\ No newline at end of file

=== modified file 'codeigniter/css/manageCoursesBody.css'
--- codeigniter/css/manageCoursesBody.css	2013-05-21 11:55:57 +0000
+++ codeigniter/css/manageCoursesBody.css	2013-05-22 11:39:03 +0000
@@ -27,7 +27,11 @@
 	margin-left:20px;
 	font-size:20px;
 	display:inline;
-	
+}
+
+#manageCourses {
+	margin-top: 67px;
+	margin-left: 60px;
 }
 
 h2.manageCourseBodyHeader{
@@ -41,20 +45,6 @@
 	display:inline;
 }
 
-h2.popupHeader{
-	margin:0;
-	margin-left:-15px;
-	margin-bottom:10px;
-	text-indent:15px;
-	padding-top:7px;
-	padding-bottom:7px;
-	font-weight:normal;
-	color:#FFF;
-	font-size:20px;
-	line-height:100%;
-	background-color:#333333;
-}
-
 #manageCoursesHeader{
 	padding:0;
 	margin:0;
@@ -76,16 +66,32 @@
 	border-bottom: 1px solid #acacac;
 }
 
+#manageCoursesMenu {
+}
+
 /*	The box where all stuff in in body is generated in.*/
 #bodyContainer{
 	float:left;
-	margin-left:90px;
 	margin-top:10px;
 	width:90%;
 	z-index:0;
 }
 
 /* Add courses popup */
+h2.popupHeader{
+	margin:0;
+	margin-left:-15px;
+	margin-bottom:10px;
+	text-indent:15px;
+	padding-top:7px;
+	padding-bottom:7px;
+	font-weight:normal;
+	color:#FFF;
+	font-size:20px;
+	line-height:100%;
+	background-color:#333333;
+}
+
 #addCourse{
 	z-index:3000000;
 	position: fixed;
@@ -124,56 +130,69 @@
 	display:table;
 }	
 
-.formColumn1{
-	display:inline-block;
-	float:left;
-	width:45%;
-}
-.formText{
-	font-size:16px;
-	padding-top:10px;
-}
-
-.formColumn2{
-	display:inline-block;
-	float:right;
-	width:45%;
-}
 
 .overflow{
 	overflow:auto;
 }
 
+/* initially display: none; -- will be shown by JS on demand */
+.manageCoursePopup {
+	display: none;
+}
+
+.manageCoursePopup form ul li {
+	list-style: none;
+	height: 30px;
+}
+
+.manageCoursePopup form ul li label {
+	float: left;
+	width: 10em;
+	clear: left;
+}
+
 input.text{
-	margin-right:5px;
-	height:30px;
 	background-color:white;
 	width:230px;
 	font-size:16px;
 	color:color:#333333;
-	display:table-cell;
 	/*Rounded corners*/
 	-webkit-border-radius: 7px;
 	-moz-border-radius: 7px;
 	border-radius: 7px;
-	float:right;
-}
-input.popupButtons{
+	padding: 5px;
+	height: auto;
+	vertical-align: bottom;
+	margin-left: 0;
+}
+
+.manageCoursePopup span {
+	font-size: 100%;
+}
+
+.manageCoursePopupMenu {
+	position: absolute;
+	bottom: 10px;
+}
+
+.popupButtons{
 	display:inline-block !important;
 	height:35px;
 	width:100px;
 	background-image: linear-gradient(to top,#fff,#f5f5f5);
-	margin-right:0px;
-	margin-left:20px;
 	/*text style*/
 	font: 16px Helvetica;
 	font-weight:bold;	
 }
 
-
-
-
-a.cp{
+.popupButtons:hover {
+	cursor: pointer;
+}
+
+
+
+
+#addCourseButton{
 	float:right;
 	position:relative;
 	right:-133px;
@@ -192,71 +211,61 @@
 	user-select: none;
 }
 
-a.cp:hover{
+#addCourseButton:hover{
 	background-color:#f5f5f5;
 	background-image: linear-gradient(to bottom,#fff,#f5f5f5);
 }
 
+.manageCourseButton:before {
+	font-family: "icomoon";
+	font-size:20px;
+	content: "C";
+	display: block;
+	width: 20px;
+	height: 20px;
+	line-height: 20px;
+}
+
 .manageCourseButton{
-	font-family: "icomoon";
-	font-size:20px;
 	display:inline-block;
 	color: #aaa;
 	border:1px solid #aaa;
+	font-size: 0;
+	line-height: 0;
 }
 .manageCourseButton:hover{
 	color:pink;
 	text-decoration:none;
 }
 
-
-
-/*	Banner is for each category */
-.banner{
-	display:block;
-	width:100%;
-	padding-left:30px;
-	height:30px;
-}
-
-/* Odd or even rows */
-.odd{
-	padding-top:5px;
-	background-color:#f5f5f5; 
-}
-
-.even{
-	padding-top:5px;
-	background-color:#fff; 
-}
-
-.column1{
-	float:left;
-	width: 300px;
-	display:inline-block;
-}
-
-.column2{
-	float:left;
-	width: 150px;
-	display:inline-block;
-}
-
-.column3{
-	float:left;
-	width: 200px;
-	display:inline-block;
-}
-
-.column4{
-	float:left;
-	width: 130px;
-	display:inline-block;
-}
-
-.column5{
-	float:right;
-	width: 30px;
-	display:inline-block;
-}
-
+.manageCoursePopup input.text {
+	font-size: 100%;
+}
+
+#manageCourses table {
+	border-collapse: collapse;
+	width: 100%;
+}
+
+#manageCourses th, #manageCourses td {
+	padding: 6px 0;
+}
+
+#manageCourses .odd td {
+	background: #fff;
+}
+
+#manageCourses .even td{
+	background: #f5f5f5;
+}
+
+#manageCourses th {
+	background: #ddd;
+	border-top: 1px #ccc solid;
+	border-bottom: 1px #ccc solid;
+	text-align: left;
+}
+
+#manageCourses th:first-child, #manageCourses td:first-child {
+	padding-left: 30px;
+}
\ No newline at end of file

=== modified file 'codeigniter/js/manageCourses.js'
--- codeigniter/js/manageCourses.js	2013-05-21 11:55:57 +0000
+++ codeigniter/js/manageCourses.js	2013-05-22 11:39:03 +0000
@@ -1,11 +1,8 @@
 /* Functions */
 $(document).ready(function(){
-	//$('#addCourse').hide();
-	$('#editCourse').hide();
-	
 	$('body').click(function(e){
-		$('#addCourse').hide();
-		$('#editCourse').hide();
+		$('#addCourse').fadeOut(300);
+		$('#editCourse').fadeOut(300);
 	});	
 	
 	$('#addCourse').click(function(e){
@@ -16,7 +13,7 @@
 	});	
 	
 	
-	$('#addCoursebutton').click(function(e){
+	$('#addCourseButton').click(function(e){
 		var target = $('#addCourse');
 		if(target.is(":hidden")){
 			target.fadeIn(300);
@@ -31,7 +28,12 @@
 	$('.manageCourseButton').click(function(e){
 		var target = $('#editCourse');
 		if(target.is(":hidden")){
-			target.fadeIn(300);
+
+			var courseID = $(this).parent().prevAll(".courseID").html();
+			var courseName = $(this).parent().prevAll(".courseName").html();
+			var courseData = $(this).parent().prevAll(".courseData").html();
+
+			showManageCourse(courseID, courseName, courseData);
 			e.stopPropagation();
 		}
 		else{
@@ -40,8 +42,25 @@
 		
 	});
 
+	$(".cancelButton").click(function(e) {
+		$(this).closest(".manageCoursePopup").fadeOut(300);
+		e.preventDefault();
+		e.stopPropagation();
+	});
+
+	$("#manageCourses table tr:odd").addClass("odd");
+	$("#manageCourses table tr:even").addClass("even");
+
 });
 
+function showManageCourse(courseID, courseName, courseData) {
+	$("#editCourse").fadeIn(300);
+	$("#editCourse #editCourseName").attr("value", courseName);
+	$("#editCourse span").html(courseID);
+	$("#editCourse #editCourseID").attr("value", courseID)
+	$("#editCourse #editCourseData").attr("value", courseData);
+}
+
 window.onkeyup = function(event){
 	if(event.keyCode==27){
 		$('#addCourse').fadeOut(300);

